@@ -107,7 +107,7 @@ class Client(object):
             self.request_headers = request_headers
 
     """Make the API call and return the response. This is separated into it's
-       own functin, so we can mock it easily for testing.
+       own function, so we can mock it easily for testing.
     """
     def _make_request(self, opener, request):
         return opener.open(request)
@@ -144,7 +144,7 @@ class Client(object):
             def http_request(*args, **kwargs):
                 if 'request_headers' in kwargs:
                     self._set_headers(kwargs['request_headers'])
-                data = json.dumps(kwargs['request_body'])\
+                data = json.dumps(kwargs['request_body']).encode('utf-8')\
                     if 'request_body' in kwargs else None
                 params = kwargs['query_params']\
                     if 'query_params' in kwargs else None
